@@ -1,31 +1,30 @@
 import base64
+import io
 import logging
 import requests
+import requests.packages.urllib3
 import time
 import urllib.parse
 import uuid
 import webbrowser
 
-import io
+from appium import webdriver
 from distutils.util import strtobool
 from PIL import Image
-
 from selenium.webdriver.common.action_chains import ActionChains
 from selenium.common.exceptions import StaleElementReferenceException
 
-from appium import webdriver
-
-import requests.packages.urllib3
+from . import __version__ as base_version
+from .utils.selenium_core import SeleniumDriverCore
 
 requests.packages.urllib3.disable_warnings()
 
 log = logging.getLogger(__name__)
 
-from .utils.selenium_core import SeleniumDriverCore
 
 class SmartDriver(SeleniumDriverCore):
     def __init__(self, driver, api_key, initialization_dict={}):
-        self.version = 'appium-0.1.25'
+        self.version = 'appium' + base_version
         self.root_elem = None
         caps = driver.desired_capabilities
         self.automation_name = caps.get('automationName', '')
@@ -54,7 +53,7 @@ class SmartDriver(SeleniumDriverCore):
         msg = ''
         if self.test_case_creation_mode:
             self._test_case_upload_screenshot(element_name)
-            element_box, needs_reload = self._test_case_get_box(element_name)
+            element_box, needs_reload, has_training_data = self._test_case_get_box(element_name)
             if element_box:
                 real_elem = self._match_bounding_box_to_web_element(element_box, multiplier=self.multiplier)
                 #element = ai_elem(real_elem.parent, real_elem, element_box, self.driver,
@@ -68,7 +67,7 @@ class SmartDriver(SeleniumDriverCore):
                                                                                                        label_url))
                 webbrowser.open(label_url)
                 while True:
-                    element_box, needs_reload = self._test_case_get_box(element_name, event_id=event_id)
+                    element_box, needs_reload, has_training_data = self._test_case_get_box(element_name, event_id=event_id)
                     if element_box is not None:
                         print('Element was labeled, moving on')
                         real_elem = self._match_bounding_box_to_web_element(element_box, multiplier=self.multiplier)
@@ -255,4 +254,4 @@ class ai_elem(webdriver.webelement.WebElement):
 
 
 class NoElementFoundException(Exception):
-    pass
\ No newline at end of file
+    pass
