@@ -22,22 +22,21 @@ if version.parse(selenium.__version__) < version.parse('4.0.0'):
 else:
     old_selenium = False
 
+from selenium import webdriver
 from selenium.webdriver.common.action_chains import ActionChains
 from selenium.webdriver.common.by import By
 from selenium.common.exceptions import StaleElementReferenceException
 
-from selenium import webdriver
-
+from . import __version__ as base_version
 from .utils.selenium_core import SeleniumDriverCore
 
 requests.packages.urllib3.disable_warnings()
 
-
 log = logging.getLogger(__name__)
 
 class SmartDriver(SeleniumDriverCore):
     def __init__(self, driver, api_key=None, initialization_dict={}):
-        self.version = 'selenium-0.1.25'
+        self.version = 'selenium-' + base_version
         self.automation_name = driver.capabilities.get('browserName', '')
         SeleniumDriverCore.__init__(self, driver, api_key, initialization_dict)
         window_size = self.driver.get_window_size()
@@ -88,7 +87,7 @@ class SmartDriver(SeleniumDriverCore):
         msg = ''
         if self.test_case_creation_mode:
             self._test_case_upload_screenshot(element_name)
-            element_box, needs_reload = self._test_case_get_box(element_name)
+            element_box, needs_reload, has_training_data = self._test_case_get_box(element_name)
             if element_box:
                 if self.use_cdp:
                     parent_elem = None
@@ -99,13 +98,30 @@ class SmartDriver(SeleniumDriverCore):
                 element = ai_elem(parent_elem, real_elem, element_box, self.driver, self.multiplier)
                 return element, self.last_test_case_screenshot_uuid, msg
             else:
+                if has_training_data:
+                    response = self._classify_full_screen(element_name)
+                    if response is not None and response['success']:
+                        element_box = response['predicted_element']
+                        self.page_offset = self.driver.execute_script('return window.pageYOffset')
+                        element_box['y'] += self.page_offset * self.multiplier
+                        if self.use_cdp:
+                            parent_elem = None
+                            real_elem = element_box
+                        else:
+                            real_elem = self._match_bounding_box_to_selenium_element(element_box, multiplier=self.multiplier)
+                            parent_elem = real_elem.parent
+                        element = ai_elem(parent_elem, real_elem, element_box, self.driver, self.multiplier)
+                        return element, self.last_test_case_screenshot_uuid, msg
+                    else:
+                        # scroll back up
+                        self._scroll_page(-100000)
                 event_id = str(uuid.uuid4())
                 label_url = f'{self.url}/testcase/label?test_case_name={urllib.parse.quote(self.test_case_uuid)}&event_id={event_id}&api_key={self.api_key}'
                 log.info('Waiting for bounding box of element {} to be drawn in the UI: \n\t{}'.format(element_name,
                                                                                                        label_url))
                 webbrowser.open(label_url)
                 while True:
-                    element_box, needs_reload = self._test_case_get_box(element_name, event_id=event_id)
+                    element_box, needs_reload, _ = self._test_case_get_box(element_name, event_id=event_id)
                     if element_box is not None:
                         if self.use_cdp:
                             parent_elem = None
@@ -389,4 +405,4 @@ class ai_elem(webdriver.remote.webelement.WebElement):
         self.send_keys('\n', click_first=False)
 
 class NoElementFoundException(Exception):
-    pass
\ No newline at end of file
+    pass
